import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { IgrNumberEventArgs } from "./igr-number-event-args";
import { Rating } from "./Rating";
import { TypeRegistrar } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { IgcRatingComponent, defineComponents } from "igniteui-webcomponents";
import { NamePatcher, getModifiedProps, isValidProp, ensureBool, ensureEnum, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
/**
 * Rating provides insight regarding others' opinions and experiences,
 * and can allow the user to submit a rating of their own
 * @cssproperty --symbol-size - The size of the symbols.
 * @cssproperty --symbol-full-color - The color of the filled symbol.
 * @cssproperty --symbol-empty-color - The color of the empty symbol.
 * @cssproperty --symbol-full-filter - The filter(s) used for the filled symbol.
 * @cssproperty --symbol-empty-filter - The filter(s) used for the empty symbol.
*/
export class IgrRating extends React.Component {
    createImplementation() {
        return new Rating();
    }
    get nativeElement() {
        return this._implementation.nativeElement;
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    constructor(props) {
        super(props);
        this.mounted = false;
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._change = null;
        this._change_wrapped = null;
        this._hover = null;
        this._hover_wrapped = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcRatingComponent);
        this._implementation = this.createImplementation();
        this._portalManager = new PortalManager("templates", () => {
            if (this.mounted) {
                this.setState({});
            }
        });
        if (typeof window !== 'undefined' && typeof document !== 'undefined') {
            this._renderer = new ReactRenderer(this._implementation.nativeElement, document, false, null, this._portalManager);
        }
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let div = React.createElement("igc-rating", {
            ref: this._getMainRef,
            id: this.props.id,
            class: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * The maximum value for the rating.
     * If there are projected symbols, the maximum value will be resolved
     * based on the number of symbols.
    */
    get max() {
        return this.i.n;
    }
    set max(v) {
        this.i.n = +v;
    }
    /**
     * The minimum value change allowed.
     * Valid values are in the interval between 0 and 1 inclusive.
    */
    get step() {
        return this.i.o;
    }
    set step(v) {
        this.i.o = +v;
    }
    /**
     * The label of the control.
    */
    get label() {
        return this.i.s;
    }
    set label(v) {
        this.i.s = v;
    }
    /**
     * A format string which sets aria-valuetext. Instances of '{0}' will be replaced
     * with the current value of the control and instances of '{1}' with the maximum value for the control.
     * Important for screen-readers and useful for localization.
    */
    get valueFormat() {
        return this.i.u;
    }
    set valueFormat(v) {
        this.i.u = v;
    }
    /**
     * The current value of the component
    */
    get value() {
        return this.i.p;
    }
    set value(v) {
        this.i.p = +v;
    }
    /**
     * Sets hover preview behavior for the component
    */
    get hoverPreview() {
        return this.i.i;
    }
    set hoverPreview(v) {
        this.i.i = ensureBool(v);
    }
    /**
     * Makes the control a readonly field.
    */
    get readOnly() {
        return this.i.l;
    }
    set readOnly(v) {
        this.i.l = ensureBool(v);
    }
    /**
     * Sets the readonly state of the component
     * @deprecated Use the `readOnly` property instead.
    */
    get readonly() {
        return this.i.k;
    }
    set readonly(v) {
        this.i.k = ensureBool(v);
    }
    /**
     * Toggles single selection visual mode.
    */
    get single() {
        return this.i.m;
    }
    set single(v) {
        this.i.m = ensureBool(v);
    }
    /**
     * Whether to reset the rating when the user selects the same value.
    */
    get allowReset() {
        return this.i.g;
    }
    set allowReset(v) {
        this.i.g = ensureBool(v);
    }
    /**
     * @deprecated Use the `--ig-size` CSS custom property instead.
    */
    get size() {
        return this.i.d;
    }
    set size(v) {
        this.i.d = ensureEnum(SizableComponentSize_$type, v);
    }
    /**
     * The disabled state of the component
    */
    get disabled() {
        return this.i.h;
    }
    set disabled(v) {
        this.i.h = ensureBool(v);
    }
    /**
     * The name attribute of the control.
    */
    get name() {
        return this.i.t;
    }
    set name(v) {
        this.i.t = v;
    }
    /**
     * Control the validity of the control.
    */
    get invalid() {
        return this.i.j;
    }
    set invalid(v) {
        this.i.j = ensureBool(v);
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("Rating");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
    /**
     * Increments the value of the control by `n` steps multiplied by the
     * step factor.
    
    */
    stepUp(n) {
        this.i.ac(n);
    }
    /**
     * Decrements the value of the control by `n` steps multiplied by
     * the step factor.
    
    */
    stepDown(n) {
        this.i.ab(n);
    }
    /**
     * Checks for validity of the control and shows the browser message if it invalid.
    
    */
    reportValidity() {
        this.i.y();
    }
    /**
     * Checks for validity of the control and emits the invalid event if it invalid.
    
    */
    checkValidity() {
        this.i.w();
    }
    /**
     * Sets a custom validation message for the control.
     * As long as `message` is not empty, the control is considered invalid.
    
    */
    setCustomValidity(message) {
        this.i.z(message);
    }
    get change() {
        return this._change;
    }
    set change(ev) {
        if (this._change_wrapped !== null) {
            this.i.change = delegateRemove(this.i.change, this._change_wrapped);
            this._change_wrapped = null;
            this._change = null;
        }
        this._change = ev;
        this._change_wrapped = (o, e) => {
            let outerArgs = new IgrNumberEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeChange) {
                this.beforeChange(this, outerArgs);
            }
            if (this._change) {
                this._change(this, outerArgs);
            }
        };
        this.i.change = delegateCombine(this.i.change, this._change_wrapped);
        if (this.i.changeChanged) {
            this.i.changeChanged();
        }
        ;
    }
    get hover() {
        return this._hover;
    }
    set hover(ev) {
        if (this._hover_wrapped !== null) {
            this.i.hover = delegateRemove(this.i.hover, this._hover_wrapped);
            this._hover_wrapped = null;
            this._hover = null;
        }
        this._hover = ev;
        this._hover_wrapped = (o, e) => {
            let outerArgs = new IgrNumberEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeHover) {
                this.beforeHover(this, outerArgs);
            }
            if (this._hover) {
                this._hover(this, outerArgs);
            }
        };
        this.i.hover = delegateCombine(this.i.hover, this._hover_wrapped);
        if (this.i.hoverChanged) {
            this.i.hoverChanged();
        }
        ;
    }
}
